# Hierarchical Poisson factorization for LensKit

> [!NOTE]
> This package is deprecated — install `lenskit[hpf]` instead.

The `lenskit-hpf` package provides hierarchical Poisson factorization,
via the [hpfrec][] implementation, for [LensKit][].

[hpfrec]: https://pypi.org/project/hpfrec
[LensKit]: https://lkpy.lenskit.org
